@@ -1,4 +1,4 @@
-# Copyright (C) 2016-2019 by the Free Software Foundation, Inc.
+# Copyright (C) 2016-2021 by the Free Software Foundation, Inc.
 #
 # This file is part of mailmanclient.
 #
@@ -15,14 +15,10 @@
 # along with mailmanclient.  If not, see <http://www.gnu.org/licenses/>.
 
 """Test Page corner cases."""
-
-from __future__ import absolute_import, print_function, unicode_literals
-
 import unittest
 
-import pytest
-from mock import Mock
-from six.moves.urllib_parse import urlsplit, parse_qs
+from unittest.mock import Mock
+from urllib.parse import urlsplit, parse_qs
 
 from mailmanclient.constants import DEFAULT_PAGE_ITEM_COUNT
 from mailmanclient.restbase.page import Page
@@ -33,7 +29,6 @@ __all__ = [
     ]
 
 
-@pytest.mark.vcr()
 class TestPage(unittest.TestCase):
 
     def test_url_simple(self):
