@@ -1,6 +1,6 @@
 # coding: utf-8
 
-# Copyright (C) 2015-2018 by the Free Software Foundation, Inc.
+# Copyright (C) 2015-2021 by the Free Software Foundation, Inc.
 #
 # This file is part of mailmanclient.
 #
@@ -18,10 +18,6 @@
 
 
 """Test unicode data when using REST endpoint."""
-
-from __future__ import absolute_import, print_function, unicode_literals
-
-import pytest
 import unittest
 
 from mailmanclient import Client
@@ -34,7 +30,6 @@ __all__ = [
     ]
 
 
-@pytest.mark.vcr()
 class TestUnicode(unittest.TestCase):
     def setUp(self):
         self._client = Client(
